==> spread-5.3.0.5-py3-none-any.whl: spread_dashboard/static/incubator/cycle.js <==
var triggers = {},
    triggerCreated = [],
    triggerUpdating;

const client = init_client(
    broker,
    function onConnect() {
        console.log('MQTT Connected');
        client.subscribe(DATA_TOPIC, {});
        client.subscribe(TRIGGERS_TOPIC + '+', {});
    },
    function onMessage(topic, message) {
        console.log('Recv: ', topic, message);
        if (topic.startsWith(TRIGGERS_TOPIC)) {
            const id = topic.substr(topic.lastIndexOf('/') + 1);
            if (message) triggers[id] = message;
            else delete triggers[id];
            if (triggerUpdating) clearTimeout(triggerUpdating);
            triggerUpdating = setTimeout(updateTriggers, 300);
        } else if (topic.startsWith(DATA_TOPIC)) {
            updateData(message);
        }
    }
);

function nextTriggerId() {
    const ids = Object.keys(triggers);
    if (ids.length === 0) return 1;

    return Math.max(...ids) + 1;
}

function updateData(data) {
    const form = $('#cycle-data');

    for (const key in data) {
        form.find('[name=' + key + ']').val(data[key]);

        if (key === 'name') {
            $('#loc-name').text(data[key]);
        } else if (key === 'period') {
            function updateSelector(i, selector) {
                selector.options.length = data[key];
                $(selector).find(' option').each(function (i, opt) {
                    opt.value = i;
                    opt.textContent = gettext('incubator_cycle_graph_some_day').replace('{0}', (i + startIndex));
                });
            }

            const cdSelector = $("#current-day");
            const dcSelector = $("#day-to-copy");
            cdSelector.each(updateSelector);
            dcSelector.each(updateSelector);
            dcSelector[0].options[cdSelector[0].selectedIndex].classList.add('hidden');
            dcSelector[0].selectedIndex = 1;
        }
    }

    drawGraph();
}

function saveData(form) {
    if (form.checkValidity()) {
        client.send(DATA_TOPIC, form2data(form), 0, true);
    }
}

function addTrigger(data) {
    const owner = $('.triggers');
    var focus = false;

    if (data === undefined) {
        focus = true;
        data = {
            day: $("#current-day").val()
        };
    }
    const form = document.createElement('form');

    if (triggerCreated.includes(parseInt(data.id))) {
        owner.append(form);
    } else {
        var addToEnd = true;
        const forms = owner.find('form').each((i, f) => {
            if (data.time < f.time.value) {
                owner[0].insertBefore(form, f);
                addToEnd = false;
                return false;
            }
        });

        if (addToEnd || forms.length === 0){
            owner.append(form);
        }
    }
    form.innerHTML = $('#template-trigger')[0].innerHTML;
    form.addEventListener('input', e => $(e.currentTarget).find(' label.submit-label').show());
    form.addEventListener('submit', setTrigger);
    for (const key in data) {
        $(form).find('[name=' + key + ']').val(data[key]);
    }
    if (focus) form.time.focus();
}

function setTrigger(e) {
    $('.triggers .submit-label').each((_, label) => {
        if (label.style.display) {
            const form = label.parentElement;
            const tId = form.id.value || nextTriggerId();
            const data = {
                day: parseInt(form.day.value),
                time: form.time.value,
                level: parseInt(form.level.value)
            };
            triggers[tId] = data;
            if (!form.id.value && !triggerCreated.includes(tId)) {
                triggerCreated.push(tId);
            }
            client.send(TRIGGERS_TOPIC + tId, data, 0, true);
        }
    });

    e.preventDefault();
}

function removeTrigger(form) {
    if (form.id.value) {
        client.send(TRIGGERS_TOPIC + form.id.value, '', 0, true);
    }

    form.remove();
}

function copyTriggers() {
    const dc = parseInt($('#day-to-copy').val());
    const cd = parseInt($('#current-day').val());
    var tId = nextTriggerId();

    Object.keys(triggers)
        .filter(tId => triggers[tId].day === cd)
        .forEach(tId => client.send(TRIGGERS_TOPIC + tId, '', 0, true));

    Object.values(triggers)
        .filter(t => t.day === dc)
        .sort((a, b) => {
            if (a.day === b.day) return (a.time > b.time) ? 1 : ( (b.time > a.time) ? -1 : 0 );
            return (a.day > b.day) ? 1 : ( (b.day > a.day) ? -1 : 0 )
        }).forEach(t => client.send(TRIGGERS_TOPIC + tId++, {...t, day: cd }, 0, true));
}

function updateTriggers() {
    $('.triggers form').remove();
    const cDay = parseInt($('#current-day').val()) || 0;
    for (const tId in triggers) {
        const trigger = triggers[tId];
        if (trigger.day === cDay) {
            addTrigger({
                id: tId,
                ...trigger
            });
        }
    }

    drawGraph();
}

function onNavi(direction) {
    const selector = $("#current-day")[0];
    if (selector.options.length > selector.selectedIndex + direction && selector.selectedIndex + direction >= 0) {
        selector.selectedIndex += direction;
        selector.onchange(selector);
    }
}

function onSelectDay(selector) {
    triggerCreated = [];
    updateTriggers();
    $('#day-to-copy').each((_, dcSelector) => {
        $(dcSelector).find('option.hidden').removeClass('hidden');
        dcSelector.value = selector.value > 0 ? selector.value - 1 : 1;
        dcSelector.options[selector.selectedIndex].classList.add('hidden');
    });
}

function form2data(form, formData) {
    formData = formData ? formData : {};
    $(form).find("input[name]").each(function (index, node) {
        if (node.type === 'checkbox') {
            formData[node.name] = node.checked;
        } else {
            formData[node.name] = node.value;
            if (node.type === 'number') {
                formData[node.name] = Boolean(node.step && node.step != parseInt(node.step, 10)) ?
                    parseFloat(formData[node.name]) :
                    parseInt(formData[node.name]);
            }
        }
    });
    $(form).find("select[name]").each(function (index, node) {
        formData[node.name] = node.value;
    });

    return formData;
}

// [номер дня, время триггера в минутах от 0:00 текущего дня, значение яркости]
// Должно быть отсортировано по дню + времени
function drawGraph() {
    const form = $('.cycle form')[0];
    const startBrightness = parseInt(form.startLevel.value);
    const fadeTime = Math.max(1, parseFloat(form.duration.value));
    const numberOfDays = parseInt(form.period.value);
    const currentDay = parseInt($("#current-day").val());
    const data = Object.values(triggers)
        .map((t) => {
            const [h, m] = t.time.split(':');
            return [t.day, h*60 + m*1, t.level]
        })
        .sort(function (a, b) {
            if (a[0] === b[0]) return (a[1] > b[1]) ? 1 : ( (b[1] > a[1]) ? -1 : 0 );
            return (a[0] > b[0]) ? 1 : ( (b[0] > a[0]) ? -1 : 0 )
        });


    if (isNaN(numberOfDays) || isNaN(currentDay))
        return;


    if (isNaN(numberOfDays) || isNaN(currentDay))
        return;

    DrawCycleGraph(document.getElementById('graphCanvasCycle'),
        data,
        startBrightness,
        fadeTime,
        gettext('incubator_cycle_graph_all_cycle'),
        gettext('incubator_cycle_graph_days'),
        numberOfDays,
        currentDay,
        null
    );
    DrawDayGraph(
        document.getElementById('graphCanvasDay'),
        data,
        startBrightness,
        fadeTime,
        gettext('incubator_cycle_graph_some_day').replace('{0}', currentDay+startIndex),
        gettext('incubator_cycle_graph_hours'),
        numberOfDays,
        currentDay,
        null
    );
}

==> spread-5.7.0.72-py3-none-any.whl: spread_dashboard/static/incubator/cycle.js <==
var triggers = {},
    triggerCreated = [],
    triggerUpdating;

const client = init_client(
    broker,
    function onConnect() {
        console.log('MQTT Connected');
        client.subscribe(DATA_TOPIC, {});
        client.subscribe(TRIGGERS_TOPIC + '+', {});
    },
    function onMessage(topic, message) {
        console.log('Recv: ', topic, message);
        if (topic.startsWith(TRIGGERS_TOPIC)) {
            const id = topic.substr(topic.lastIndexOf('/') + 1);
            if (message) triggers[id] = message;
            else delete triggers[id];
            if (triggerUpdating) clearTimeout(triggerUpdating);
            triggerUpdating = setTimeout(updateTriggers, 300);
        } else if (topic.startsWith(DATA_TOPIC)) {
            updateData(message);
        }
    }
);

function nextTriggerId() {
    const ids = Object.keys(triggers);
    if (ids.length === 0) return 1;

    return Math.max(...ids) + 1;
}

function updateData(data) {
    const form = $('#cycle-data');

    for (const key in data) {
        form.find('[name=' + key + ']').val(data[key]);

        if (key === 'name') {
            $('#loc-name').text(data[key]);
        } else if (key === 'period') {
            function updateSelector(i, selector) {
                selector.options.length = data[key];
                $(selector).find(' option').each(function (i, opt) {
                    opt.value = i;
                    opt.textContent = gettext('incubator_cycle_graph_some_day').replace('{0}', (i + startIndex));
                });
            }

            const cdSelector = $("#current-day");
            const dcSelector = $("#day-to-copy");
            cdSelector.each(updateSelector);
            dcSelector.each(updateSelector);
            dcSelector[0].options[cdSelector[0].selectedIndex].classList.add('hidden');
            dcSelector[0].selectedIndex = 1;
        }
    }

    drawGraph();
}

function saveData(form) {
    if (form.checkValidity()) {
        client.send(DATA_TOPIC.replace(LOCAL, SET), form2data(form), 0, false);
    }
}

function addTrigger(data) {
    const owner = $('.triggers');
    var focus = false;

    if (data === undefined) {
        focus = true;
        data = {
            day: $("#current-day").val()
        };
    }
    const form = document.createElement('form');

    if (triggerCreated.includes(parseInt(data.id))) {
        owner.append(form);
    } else {
        var addToEnd = true;
        const forms = owner.find('form').each((i, f) => {
            if (data.time < f.time.value) {
                owner[0].insertBefore(form, f);
                addToEnd = false;
                return false;
            }
        });

        if (addToEnd || forms.length === 0){
            owner.append(form);
        }
    }
    form.innerHTML = $('#template-trigger')[0].innerHTML;
    form.addEventListener('input', e => $(e.currentTarget).find(' label.submit-label').show());
    form.addEventListener('submit', setTrigger);
    for (const key in data) {
        $(form).find('[name=' + key + ']').val(data[key]);
    }
    if (focus) form.time.focus();
}

function setTrigger(e) {
    $('.triggers .submit-label').each((_, label) => {
        if (label.style.display) {
            const form = label.parentElement;
            const tId = form.id.value || nextTriggerId();
            const data = {
                day: parseInt(form.day.value),
                time: form.time.value,
                level: parseInt(form.level.value)
            };
            triggers[tId] = data;
            if (!form.id.value && !triggerCreated.includes(tId)) {
                triggerCreated.push(tId);
            }
            client.send(TRIGGERS_TOPIC.replace(LOCAL, SET) + tId, data, 0, false);
        }
    });

    e.preventDefault();
}

function removeTrigger(form) {
    if (form.id.value) {
        client.send(TRIGGERS_TOPIC.replace(LOCAL, RESET) + form.id.value, JSON.stringify({}), 0, false);
    }

    /*
    Плашка триггера удаляется при удалении сервером соответствующего топика
    Принудительное удаление дива не требуется
    */

    // form.remove();
}

function copyTriggers() {
    const dc = parseInt($('#day-to-copy').val());
    const cd = parseInt($('#current-day').val());
    var tId = nextTriggerId();

    Object.keys(triggers)
        .filter(tId => triggers[tId].day === cd)
        .forEach(tId => client.send(TRIGGERS_TOPIC.replace(LOCAL, SET) + tId, '', 0, false));

    Object.values(triggers)
        .filter(t => t.day === dc)
        .sort((a, b) => {
            if (a.day === b.day) return (a.time > b.time) ? 1 : ( (b.time > a.time) ? -1 : 0 );
            return (a.day > b.day) ? 1 : ( (b.day > a.day) ? -1 : 0 )
        }).forEach(t => client.send(TRIGGERS_TOPIC.replace(LOCAL, SET) + tId++, {...t, day: cd }, 0, false));
}

function updateTriggers() {
    $('.triggers form').remove();
    const cDay = parseInt($('#current-day').val()) || 0;
    for (const tId in triggers) {
        const trigger = triggers[tId];
        if (trigger.day === cDay) {
            addTrigger({
                id: tId,
                ...trigger
            });
        }
    }

    drawGraph();
}

function onNavi(direction) {
    const selector = $("#current-day")[0];
    if (selector.options.length > selector.selectedIndex + direction && selector.selectedIndex + direction >= 0) {
        selector.selectedIndex += direction;
        selector.onchange(selector);
    }
}

function onSelectDay(selector) {
    triggerCreated = [];
    updateTriggers();
    $('#day-to-copy').each((_, dcSelector) => {
        $(dcSelector).find('option.hidden').removeClass('hidden');
        dcSelector.value = selector.value > 0 ? selector.value - 1 : 1;
        dcSelector.options[selector.selectedIndex].classList.add('hidden');
    });
}

function form2data(form, formData) {
    formData = formData ? formData : {};
    $(form).find("input[name]").each(function (index, node) {
        if (node.type === 'checkbox') {
            formData[node.name] = node.checked;
        } else {
            formData[node.name] = node.value;
            if (node.type === 'number') {
                formData[node.name] = Boolean(node.step && node.step != parseInt(node.step, 10)) ?
                    parseFloat(formData[node.name]) :
                    parseInt(formData[node.name]);
            }
        }
    });
    $(form).find("select[name]").each(function (index, node) {
        formData[node.name] = node.value;
    });

    return formData;
}

// [номер дня, время триггера в минутах от 0:00 текущего дня, значение яркости]
// Должно быть отсортировано по дню + времени
function drawGraph() {
    const form = $('.cycle form')[0];
    const startBrightness = parseInt(form.startLevel.value);
    const fadeTime = Math.max(1, parseFloat(form.duration.value));
    const numberOfDays = parseInt(form.period.value);
    const currentDay = parseInt($("#current-day").val());
    const data = Object.values(triggers)
        .map((t) => {
            const [h, m] = t.time.split(':');
            return [t.day, h*60 + m*1, t.level]
        })
        .sort(function (a, b) {
            if (a[0] === b[0]) return (a[1] > b[1]) ? 1 : ( (b[1] > a[1]) ? -1 : 0 );
            return (a[0] > b[0]) ? 1 : ( (b[0] > a[0]) ? -1 : 0 )
        });


    if (isNaN(numberOfDays) || isNaN(currentDay))
        return;


    if (isNaN(numberOfDays) || isNaN(currentDay))
        return;

    DrawCycleGraph(document.getElementById('graphCanvasCycle'),
        data,
        startBrightness,
        fadeTime,
        gettext('incubator_cycle_graph_all_cycle'),
        gettext('incubator_cycle_graph_days'),
        numberOfDays,
        currentDay,
        null
    );
    DrawDayGraph(
        document.getElementById('graphCanvasDay'),
        data,
        startBrightness,
        fadeTime,
        gettext('incubator_cycle_graph_some_day').replace('{0}', currentDay+startIndex),
        gettext('incubator_cycle_graph_hours'),
        numberOfDays,
        currentDay,
        null
    );
}
